package jp.jbug.example.seam;

import static javax.persistence.PersistenceContextType.EXTENDED;

import java.io.Serializable;

import javax.ejb.Remove;
import javax.ejb.Stateful;
import javax.persistence.EntityManager;
import javax.persistence.PersistenceContext;

import org.jboss.seam.annotations.Begin;
import org.jboss.seam.annotations.Destroy;
import org.jboss.seam.annotations.End;
import org.jboss.seam.annotations.In;
import org.jboss.seam.annotations.Logger;
import org.jboss.seam.annotations.Name;
import org.jboss.seam.annotations.Out;
import org.jboss.seam.core.Events;
import org.jboss.seam.faces.FacesMessages;
import org.jboss.seam.log.Log;

@Stateful
@Name("blogEntryAction")
public class BlogEntryAction implements Serializable, IBlogEntry {

    private static final long serialVersionUID = 1L;

    @PersistenceContext(type = EXTENDED)
    private EntityManager em;

    @In(required = false)
    @Out(required = false)
    private BlogEntry blogEntry;

    @In
    private FacesMessages facesMessages;

    @In
    private Events events;

    @Logger
    private Log log;

    @Begin
    public void init() {
        log.info("ブログ登録画面前処理");
    }

    @Begin
    public void init(BlogEntry entry) {
        log.info("ブログ変更画面前処理");
        this.blogEntry = entry;
    }

    @Begin(join=true)
    public void confirm() {
        //no op
    }

    @End
    public void save() {
        em.persist(blogEntry);
        facesMessages.add("登録しました");
        log.info("#{blogEntry.blogEntryId} entried");
        events.raiseTransactionSuccessEvent("blogUpdated");
    }

    @End
    public void update() {
        facesMessages.add("変更しました");
        log.info("#{blogEntry.blogEntryId} 変更しました");
        events.raiseTransactionSuccessEvent("blogUpdated");
    }

    @Remove
    @Destroy
    public void destroy() {
        log.info(this + "　は破棄されました");
    }

}
